@@ -5,7 +5,7 @@ from omegaconf import MISSING
 
 from fseval.pipeline.cv import CrossValidator
 from fseval.pipeline.dataset import DatasetLoader
-from fseval.types import AbstractStorageProvider, Callback
+from fseval.types import AbstractStorage, Callback
 
 
 @dataclass
@@ -13,4 +13,4 @@ class Pipeline:
     callbacks: Dict[str, Callback] = field(default_factory=dict)
     dataset: DatasetLoader = MISSING
     cv: CrossValidator = MISSING
-    storage_provider: AbstractStorageProvider = MISSING
+    storage: AbstractStorage = MISSING
