@@ -1,8 +1,9 @@
 import logging
 from dataclasses import dataclass
+from typing import Optional
 
-from fseval.pipeline.estimator import Estimator, TaskedEstimatorConfig
-from fseval.pipeline.resample import Resample, ResampleConfig
+from fseval.pipeline.estimator import Estimator
+from fseval.pipeline.resample import Resample
 from omegaconf import MISSING
 
 from .._pipeline import Pipeline
@@ -10,30 +11,20 @@ from .._pipeline import Pipeline
 logger = logging.getLogger(__name__)
 
 
-@dataclass
-class RankAndValidateConfig:
-    _target_: str = (
-        "fseval.pipelines.rank_and_validate._components.BootstrappedRankAndValidate"
-    )
-    name: str = "rank-and-validate"
-    resample: ResampleConfig = MISSING
-    ranker: TaskedEstimatorConfig = MISSING
-    validator: TaskedEstimatorConfig = MISSING
-    n_bootstraps: int = MISSING
-    all_features_to_select: str = MISSING
-
-
 @dataclass
 class RankAndValidatePipeline(Pipeline):
     """Instantiated version of `RankAndValidateConfig`: the actual pipeline
     implementation."""
 
-    name: str = MISSING
+    pipeline: str = MISSING
     resample: Resample = MISSING
     ranker: Estimator = MISSING
     validator: Estimator = MISSING
     n_bootstraps: int = MISSING
+    n_jobs: Optional[int] = MISSING
     all_features_to_select: str = MISSING
+    upload_ranking_scores: bool = MISSING
+    upload_validation_scores: bool = MISSING
 
     def _get_config(self):
         return {
