@@ -42,7 +42,7 @@ class RankingValidator(Experiment, RankAndValidatePipeline):
         yield self.ranker
 
     def prefit(self):
-        self.ranker._load_cache(self._cache_filename, self.storage_provider)
+        self.ranker._load_cache(self._cache_filename, self.storage)
 
     def fit(self, X, y):
         self.logger.info(f"fitting ranker: " + TerminalColor.yellow(self.ranker.name))
@@ -50,7 +50,7 @@ class RankingValidator(Experiment, RankAndValidatePipeline):
         super(RankingValidator, self).fit(X, y)
 
     def postfit(self):
-        self.ranker._save_cache(self._cache_filename, self.storage_provider)
+        self.ranker._save_cache(self._cache_filename, self.storage)
 
     def _scores_to_ranking(self, scores):
         """Converts a scoring vector to a ranking vector, or standardizes an existing
@@ -77,7 +77,13 @@ class RankingValidator(Experiment, RankAndValidatePipeline):
         """Normalized estimated feature importances. The summation of the importances
         vector is always 1."""
 
+        # get ranker feature importances, check whether all components > 0
         feature_importances = np.asarray(self.ranker.feature_importances_)
+        assert not (
+            feature_importances < 0
+        ).any(), "estimated feature importances must be strictly positive."
+
+        # normalize
         feature_importances = feature_importances / sum(feature_importances)
 
         return feature_importances
