@@ -9,7 +9,6 @@ from fseval.types import TerminalColor as tc
 from fseval.utils.dict_utils import dict_flatten
 from omegaconf import MISSING
 from sklearn.base import clone
-from tqdm import tqdm
 
 from .._experiment import Experiment
 from ._config import RankAndValidatePipeline
@@ -293,7 +292,7 @@ class BootstrappedRankAndValidate(Experiment, RankAndValidatePipeline):
                     "scale_string": "x^5",
                     "color_scheme": "redyellowblue",
                     "reverse_colorscheme": "",
-                    "text_threshold": "0.95",
+                    "text_threshold": "datum.relative_performance >= 0.5 && datum.relative_performance <= 0.95",
                 },
             )
 
@@ -318,14 +317,21 @@ class BootstrappedRankAndValidate(Experiment, RankAndValidatePipeline):
                 string_fields={
                     "title": "Algorithm Stability",
                     "subtitle": "→ Mean stdev of feature importances. Lower is better.",
-                    "aggregation_op": "stdev",
-                    "scale_type": "quantile",
-                    "color_exponent": "5",
-                    "opacity_exponent": "0",
-                    "scale_string": "qnt",
-                    "color_scheme": "reds",
+                    "validator_option_1": "",
+                    "validator_option_2": "",
+                    "filter3": "datum['group'] === 'estimated'",
+                    "extra_agg_op": "stdev",
+                    "extra_groupby": "feature_index",
+                    "best_run_op": "argmin",
+                    "aggregation_op": "mean",
+                    "scale_type": "pow",
+                    "color_exponent": "0.2",
+                    "opacity_scale_type": "pow",
+                    "opacity_exponent": "0.",
+                    "scale_string": "x^0.2",
+                    "color_scheme": "redyellowgreen",
                     "reverse_colorscheme": "",
-                    "text_threshold": "0.95",
+                    "text_threshold": "datum.relative_performance >= 0.05 && datum.relative_performance <= 0.7",
                 },
             )
 
@@ -351,13 +357,15 @@ class BootstrappedRankAndValidate(Experiment, RankAndValidatePipeline):
                     "title": "Fitting time (seconds)",
                     "subtitle": "→ As mean over all bootstraps",
                     "aggregation_op": "mean",
+                    "filter3": "datum['fit_time'] > 0.000030",
+                    "best_run_op": "argmin",
                     "scale_type": "pow",
                     "color_exponent": "0.1",
-                    "opacity_exponent": "15",
+                    "opacity_exponent": "0",
                     "scale_string": "x^0.1",
                     "color_scheme": "redyellowblue",
-                    "reverse_colorscheme": "true",
-                    "text_threshold": "0.95",
+                    "reverse_colorscheme": "",
+                    "text_threshold": "datum.relative_performance >= 0.001 && datum.relative_performance <= 0.3",
                 },
             )
 
